Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(379)

Unified Diff: test/webkit/fast/js/Promise-static-cast.js

Issue 200763012: Remove Promise.cast (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/mjsunit/es6/promises.js ('k') | test/webkit/fast/js/Promise-static-cast-expected.txt » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/webkit/fast/js/Promise-static-cast.js
diff --git a/test/webkit/fast/js/Promise-static-cast.js b/test/webkit/fast/js/Promise-static-cast.js
index 48049398b069171b2876bff78be06999a507ab04..2c1eb2f72ab74cfaf7469bbfde0390de6ac3281a 100644
--- a/test/webkit/fast/js/Promise-static-cast.js
+++ b/test/webkit/fast/js/Promise-static-cast.js
@@ -23,23 +23,23 @@
// Flags: --harmony
'use strict';
-description('Test Promise.cast');
+description('Test Promise.resolve as cast');
var result = undefined;
var result2 = undefined;
var resolve;
var value = new Promise(function (r) { resolve = r;} );
-var promise = Promise.cast(value);
+var promise = Promise.resolve(value);
-// If [[IsPromise]] is true, Promise.cast simply returns argument.
+// If [[IsPromise]] is true, Promise.resolve simply returns argument.
shouldBe('promise', 'value');
promise.then(function(res) {
result = res;
shouldBeEqualToString('result', 'hello');
- return Promise.cast(42).then(function (res) {
+ return Promise.resolve(42).then(function (res) {
result2 = res;
shouldBe('result2', '42');
});
« no previous file with comments | « test/mjsunit/es6/promises.js ('k') | test/webkit/fast/js/Promise-static-cast-expected.txt » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698